
void bi207( Double_t minutes = 10, Int_t bins = 150, Double_t emin = 0, Double_t emax = 3000)
{
    Double_t seconds = minutes * 60;

    vector<bool> enable = {true, true, true, true, true, true};

    vector<TString> filename;
    filename.push_back("../output/bi207_482_K.root"); 
    filename.push_back("../output/bi207_482_L.root"); 
    filename.push_back("../output/bi207_976_K.root"); 
    filename.push_back("../output/bi207_976_L.root"); 
    filename.push_back("../output/bi207_1682_K.root"); 
    filename.push_back("../output/bi207_1682_L.root"); 

    vector<double> intensity;
    intensity.push_back(15.62); // per 1000 decays
    intensity.push_back(4.38);
    intensity.push_back(72.43);
    intensity.push_back(18.38);
    intensity.push_back(0.2522);
    intensity.push_back(0.0403);
    for (auto& i : intensity) i /= 1000.;

    // set some parameters
    double A0    = 398e3; // Start activity in Bq
    double years = 8.0;   // years since source was made
    double t12   = 31.6;  // half-life
    double A     = A0 * TMath::Exp(- years * TMath::Log(2) / t12);
    cout << "\n Activity: " << A << " Bq\n" << endl;
    
    // veto threshold
    double vetoThres = 100; // keV
    
    // Canvas
    TCanvas *canvas = new TCanvas("c1", "multipads", 900, 700);
    canvas -> Clear();

    // Prepare histograms
    TH1F *hSingles = new TH1F("hSingles", "hSingles", bins, emin, emax);
    TH1F *hVetoed = new TH1F("hVetoed", "hVetoed", bins, emin, emax);

    // loop over bi207 lines
    for (int i = 0; i < intensity.size(); i++) 
    {
        // Open root file
        TFile *f = TFile::Open(filename[i]);
        
        // Get TTree
        TTree *t = (TTree*)f -> Get("Detector");

        // Normalization
        Double_t norm = ((TParameter<double>*)(t->GetUserInfo()->FindObject("NORMALIZATION")))->GetVal();

	    // Calculate scaling factor
	    Double_t sf = intensity[i] * seconds * A / norm;
        cout << " Scaling factor: " << sf << endl;

        // Singles spectrum
        string na = Form("ha%i", i);
        TH1F * ha = new TH1F(na.data(), na.data(), bins, emin, emax);
        t -> Draw(Form("EDepSignal >> %s", na.c_str())); 
        ha -> Scale(sf);
        hSingles -> Add(ha);

        // Vetoed spectrum
        TCut veto = Form("EDepVeto < %.1f", vetoThres);
        string nb = Form("hb%i", i);
        TH1F * hb = new TH1F(nb.data(), nb.data(), bins, emin, emax);
        t -> Draw(Form("EDepSignal >> %s", nb.c_str()), veto); 
        hb -> Scale(sf);
        hVetoed -> Add(hb);

        f->Close();
    }

    // kill 2 first bins
    hSingles -> SetBinContent(1, 0); // kill bin 1
    hSingles -> SetBinContent(2, 0); // kill bin 2

    // draw singles spectrum
    hSingles -> Draw();

    // "detach" the histograms from file and close file
    hSingles -> SetDirectory(0); 
    hVetoed -> SetDirectory(0); 

    // Open output file
    TFile *fo = TFile::Open("bi207_his.root", "recreate");
    
    // write histograms to new file
    hSingles -> Write();
    hVetoed -> Write();

	cout << "\n Histograms written to: " << fo->GetName() << endl << endl;
    fo -> Close();
}
