//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
#include "VKRecorderRootMessenger.hh"

#include "G4UIcmdWithADoubleAndUnit.hh"
#include "G4UIcmdWith3VectorAndUnit.hh"
#include "G4UIcmdWithAnInteger.hh"
#include "G4UIcommand.hh"
#include "G4UIdirectory.hh"
#include "G4UIcmdWithABool.hh"
#include "G4UIcmdWithADouble.hh"
#include "G4UIcmdWithAString.hh"
#include "G4UIcmdWithoutParameter.hh"


VKRecorderRootMessenger::VKRecorderRootMessenger(VKRecorderRoot* pRecorderRoot)
 : fRecorderRoot(pRecorderRoot)
{
    // Setup a command directory for detector controls with guidance
    fRecorderRootDir = new G4UIdirectory("/VK/output/");
    fRecorderRootDir -> SetGuidance("ROOT output control");
       
    // Various commands for modifying ROOT output
    fZeroSuppressionCmd = new G4UIcmdWithABool("/VK/output/zeroSuppression", this);
    fZeroSuppressionCmd -> SetGuidance("Enable/disable zero suppression for ROOT output.");
    fZeroSuppressionCmd -> AvailableForStates(G4State_PreInit, G4State_Idle);
    fZeroSuppressionCmd -> SetToBeBroadcasted(false);

    fOpenFileCmd = new G4UIcmdWithAString("/VK/output/openFile", this);
    fOpenFileCmd -> SetGuidance("Open a new ROOT output file with name provided.");
    fOpenFileCmd -> SetParameterName("filename", false);
    fOpenFileCmd -> AvailableForStates(G4State_PreInit, G4State_Idle);
    fOpenFileCmd -> SetToBeBroadcasted(false);

    fCloseFileCmd = new G4UIcmdWithoutParameter("/VK/output/closeFile", this);
    fCloseFileCmd -> SetGuidance("Write data to current ROOT file and close file.");
    fCloseFileCmd -> AvailableForStates(G4State_PreInit, G4State_Idle);
    fCloseFileCmd -> SetToBeBroadcasted(false);
}


VKRecorderRootMessenger::~VKRecorderRootMessenger()
{
    delete fZeroSuppressionCmd;
    delete fOpenFileCmd;
    delete fCloseFileCmd;
}


void VKRecorderRootMessenger::SetNewValue(G4UIcommand* command, G4String newValue)
{
    if (command == fZeroSuppressionCmd)
    {
        fRecorderRoot -> SetZeroSuppressionOn(fZeroSuppressionCmd -> GetNewBoolValue(newValue));
    }
    else if (command == fOpenFileCmd)
    {
        fRecorderRoot -> SetRootFilename(newValue);
    }
    else if (command == fCloseFileCmd)
    {
        fRecorderRoot -> WriteToRootFileAndClose();
    }
}
