//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#include "VKScintillatorSensitiveDetector.hh"
#include "VKScintillatorHit.hh"

#include "G4VPhysicalVolume.hh"
#include "G4LogicalVolume.hh"
#include "G4Track.hh"
#include "G4Step.hh"
#include "G4ParticleDefinition.hh"
#include "G4VTouchable.hh"
#include "G4TouchableHistory.hh"
#include "G4ios.hh"
#include "G4VProcess.hh"


VKScintillatorSensitiveDetector::VKScintillatorSensitiveDetector(G4String name)
 : G4VSensitiveDetector(name)
{
    fScintCollection = NULL;
    collectionName.insert(name+"_HitCollection");
}


VKScintillatorSensitiveDetector::~VKScintillatorSensitiveDetector() 
{
    // do nothing
}


void VKScintillatorSensitiveDetector::Initialize(G4HCofThisEvent* hitsCE)
{
    fScintCollection = new VKScintillatorHitsCollection(SensitiveDetectorName, collectionName[0]);

    // A way to keep all the hits of this event in one place if needed
    static G4int hitsCID = -1;
    if (hitsCID<0) {
        hitsCID = GetCollectionID(0);
    }
    hitsCE -> AddHitsCollection(hitsCID, fScintCollection);
}


G4bool VKScintillatorSensitiveDetector::ProcessHits(G4Step* aStep,G4TouchableHistory* )
{
    G4double edep = aStep -> GetTotalEnergyDeposit();
    if (edep==0.) return false; // No energy deposited so do not count as hit

    // pre-step point and volume
    G4StepPoint* thePrePoint = aStep -> GetPreStepPoint();
    G4TouchableHistory* theTouchable = (G4TouchableHistory*)(thePrePoint->GetTouchable());
    G4VPhysicalVolume* thePrePV = theTouchable->GetVolume();

    // post-step point
    G4StepPoint* thePostPoint = aStep->GetPostStepPoint();

    // Get the average position of the hit
    G4ThreeVector pos = thePrePoint->GetPosition() + thePostPoint->GetPosition();
    pos/=2.;

    // Create hit
    VKScintillatorHit* scintHit = new VKScintillatorHit(thePrePV);

    // Set energy and position
    scintHit -> SetEdep(edep);
    scintHit -> SetPos(pos);

    fScintCollection->insert(scintHit);

    return true;
}


void VKScintillatorSensitiveDetector::EndOfEvent(G4HCofThisEvent* ) 
{
    // do nothing
}


void VKScintillatorSensitiveDetector::clear() 
{
    // do nothing
} 


void VKScintillatorSensitiveDetector::DrawAll() 
{
    // do nothing
} 


void VKScintillatorSensitiveDetector::PrintAll() 
{
    // do nothing
} 
