//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//

#include "VKSiPMHit.hh"
#include "G4ios.hh"
#include "G4VVisManager.hh"
#include "G4Colour.hh"
#include "G4VisAttributes.hh"
#include "G4LogicalVolume.hh"
#include "G4VPhysicalVolume.hh"

G4ThreadLocal G4Allocator<VKSiPMHit>* VKSiPMHitAllocator=0;


VKSiPMHit::VKSiPMHit()
 : fSiPMNumber(-1),
   fPhotons(0),
   fPhysVol(0),
   fDrawit(false) 
{
    // do nothing
}


VKSiPMHit::~VKSiPMHit() 
{
    // do nothing
}


VKSiPMHit::VKSiPMHit(const VKSiPMHit &right) : G4VHit()
{
    fSiPMNumber=right.fSiPMNumber;
    fPhotons=right.fPhotons;
    fPhysVol=right.fPhysVol;
    fDrawit=right.fDrawit;
}


const VKSiPMHit& VKSiPMHit::operator=(const VKSiPMHit &right)
{
  fSiPMNumber = right.fSiPMNumber;
  fPhotons = right.fPhotons;
  fPhysVol = right.fPhysVol;
  fDrawit = right.fDrawit;
  return *this;
}


G4int VKSiPMHit::operator==(const VKSiPMHit &right) const 
{
    return (fSiPMNumber==right.fSiPMNumber);
}


void VKSiPMHit::Draw()
{
    if(fDrawit && fPhysVol) // ReDraw only the SiPMs that have hit counts > 0
    { 
        // Also need a physical volume to be able to draw anything
        G4VVisManager* pVVisManager = G4VVisManager::GetConcreteInstance();
        if (pVVisManager) // Make sure that the VisManager exists
        {
            G4VisAttributes attribs(G4Colour(1.,0.,0.));
            attribs.SetForceSolid(true);
            G4RotationMatrix rot;
            if (fPhysVol->GetRotation()) rot = *(fPhysVol->GetRotation()); // If a rotation is defined use it
            G4Transform3D trans(rot, fPhysVol->GetTranslation()); // Create transform
            pVVisManager->Draw(*fPhysVol, attribs, trans); // Draw it
        }
    }
}


void VKSiPMHit::Print() 
{
    // do nothing
}
